@@ -3,7 +3,7 @@ package Image::Xpm;    # Documented at the __END__
 use strict;
 
 use vars qw($VERSION @ISA);
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 use Image::Base;
 
@@ -293,7 +293,7 @@ sub del_colour { # Object method
     }
 
     delete $self->{-palette}{$cc};
-    delete $self->{-colours}{$colour};
+    delete $self->{-cindex}{$colour};
     $self->{-ncolours}--;
 
     1;
